==> haskell-rio-prettyprint-0.1.0.0-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-rio-prettyprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: rio-prettyprint
version: 0.1.0.0
id: rio-prettyprint-0.1.0.0-FT8ZqpQ1JIbAh2tP2eiKsU
key: rio-prettyprint-0.1.0.0-FT8ZqpQ1JIbAh2tP2eiKsU
license: BSD-3-Clause
copyright: 2018-2019 FP Complete
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/commercialhaskell/stack#readme
synopsis: Pretty-printing for RIO
category: Development
abi: 3078d16b3926c038e60572d85292c090
exposed: True
exposed-modules:
    RIO.PrettyPrint RIO.PrettyPrint.DefaultStyles
    RIO.PrettyPrint.StylesUpdate RIO.PrettyPrint.Types
    Text.PrettyPrint.Leijen.Extended
hidden-modules: Paths_rio_prettyprint
import-dirs: /usr/lib/ghc-8.6.5/site-local/rio-prettyprint-0.1.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/rio-prettyprint-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/rio-prettyprint-0.1.0.0
hs-libraries: HSrio-prettyprint-0.1.0.0-FT8ZqpQ1JIbAh2tP2eiKsU
depends:
    Cabal-2.4.0.1 aeson-1.4.4.0-HZF4dQ7ymfT471uy0aBwyJ
    annotated-wl-pprint-0.7.0-DGkZQ2VEej1K9q8cmlJu7D
    ansi-terminal-0.9.1-7greAUREMxf1pgDTp3Pb1X array-0.5.3.0
    base-4.12.0.0 colour-2.3.5-KhGPW5qZVuqBSMjjUiJ91B mtl-2.2.2
    path-0.6.1-JDHmLdaHolWIKwZFfELRMA
    rio-0.1.11.0-8mwr5j0CL9r2TyMzDm1qRc text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-rio-prettyprint/html/rio-prettyprint.haddock
haddock-html: /usr/share/doc/haskell-rio-prettyprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rio-prettyprint-0.1.0.0-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-rio-prettyprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: rio-prettyprint
version: 0.1.0.0
id: rio-prettyprint-0.1.0.0-69EC7M1mfWzHHUnBSVHWju
key: rio-prettyprint-0.1.0.0-69EC7M1mfWzHHUnBSVHWju
license: BSD-3-Clause
copyright: 2018-2019 FP Complete
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/commercialhaskell/stack#readme
synopsis: Pretty-printing for RIO
category: Development
abi: c01ad83f0fda38fa0adcca03144aa118
exposed: True
exposed-modules:
    RIO.PrettyPrint RIO.PrettyPrint.DefaultStyles
    RIO.PrettyPrint.StylesUpdate RIO.PrettyPrint.Types
    Text.PrettyPrint.Leijen.Extended
hidden-modules: Paths_rio_prettyprint
import-dirs: /usr/lib/ghc-8.6.5/site-local/rio-prettyprint-0.1.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/rio-prettyprint-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/rio-prettyprint-0.1.0.0
hs-libraries: HSrio-prettyprint-0.1.0.0-69EC7M1mfWzHHUnBSVHWju
depends:
    Cabal-2.4.0.1 aeson-1.4.4.0-KwovUsQGNt8PPlzoq6sTW
    annotated-wl-pprint-0.7.0-DGkZQ2VEej1K9q8cmlJu7D
    ansi-terminal-0.9.1-7greAUREMxf1pgDTp3Pb1X array-0.5.3.0
    base-4.12.0.0 colour-2.3.5-KhGPW5qZVuqBSMjjUiJ91B mtl-2.2.2
    path-0.6.1-2ZddSxHdIfrEvkAJQ8n4v4
    rio-0.1.11.0-8mwr5j0CL9r2TyMzDm1qRc text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-rio-prettyprint/html/rio-prettyprint.haddock
haddock-html: /usr/share/doc/haskell-rio-prettyprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
